@@ -145,19 +145,13 @@ class ConfUtil:
 
     @classmethod
     def _init(cls, conf):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.uuids(conf):
-            cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf):
-        try:
-            cls.CONN = configparser.ConfigParser()
-            cls.CONN.read(conf, encoding='utf-8')
-            cls.CFID = UniUtil.uuids(conf)
-        except Exception as e:
-            print("conf init failed, please check the config", e)
+        cls.CONN = configparser.ConfigParser()
+        cls.CONN.read(conf, encoding='utf-8')
+        cls.CFID = UniUtil.uuids(conf)
 
     @classmethod
     def get_items(cls, conf, section):
@@ -285,6 +279,18 @@ class DtUtil:
     if UniUtil.get_os() == 'Windows':
         locale.setlocale(locale.LC_CTYPE, 'chinese')
 
+    @staticmethod
+    def ndt():
+        """当前日期
+        """
+        return dt.datetime.now()
+
+    @staticmethod
+    def nts():
+        """当前时间戳（13位毫秒级）
+        """
+        return int(dt.datetime.now().timestamp() * 1000)
+
     @staticmethod
     def convert_ts_to_date(src_ts_ms: int):
         """把13位毫秒级时间戳格式化日期
@@ -579,18 +585,12 @@ class InfluxUtil:
 
     @classmethod
     def _init(cls, conf: dict):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
-            cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf: dict):
-        try:
-            cls.CONN = InfluxDBClient(**conf)
-            cls.CFID = UniUtil.get_uuid(conf)
-        except Exception as e:
-            print("influxdb init failed, please check the config", e)
+        cls.CONN = InfluxDBClient(**conf)
+        cls.CFID = UniUtil.get_uuid(conf)
 
     @classmethod
     def exec_sql(cls, conf: dict, sql: str):
@@ -676,23 +676,12 @@ class MysqlUtil:
 
     @classmethod
     def _init(cls, conf: dict):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
-            cls.connect(conf)
-        else:
-            try:
-                cls.CONN.ping()
-            except Exception as e:
-                cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf: dict):
-        try:
-            cls.CONN = pymysql.connect(**conf)
-            cls.CFID = UniUtil.get_uuid(conf)
-        except Exception as e:
-            print("mysql init failed, please check the config", e)
+        cls.CONN = pymysql.connect(**conf)
+        cls.CFID = UniUtil.get_uuid(conf)
 
     @classmethod
     def get(cls, conf: dict, sql: str):
@@ -729,20 +718,14 @@ class ShellUtil:
 
     @classmethod
     def _init(cls, conf: dict):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
-            cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf: dict):
-        try:
-            cls.CONN = paramiko.SSHClient()
-            cls.CONN.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-            cls.CONN.connect(**conf)
-            cls.CFID = UniUtil.get_uuid(conf)
-        except Exception as e:
-            print("shell init failed, please check the config", e)
+        cls.CONN = paramiko.SSHClient()
+        cls.CONN.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+        cls.CONN.connect(**conf)
+        cls.CFID = UniUtil.get_uuid(conf)
 
     @classmethod
     def exec(cls, conf: dict, cmd: str):
@@ -774,18 +757,12 @@ class MinioUtil:
 
     @classmethod
     def _init(cls, conf: dict):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
-            cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf: dict):
-        try:
-            cls.CONN = minio.Minio(**conf)
-            cls.CFID = UniUtil.get_uuid(conf)
-        except Exception as e:
-            print("minio init failed, please check the config", e)
+        cls.CONN = minio.Minio(**conf)
+        cls.CFID = UniUtil.get_uuid(conf)
 
     @classmethod
     def upload(cls, conf: dict, bucket: str, filepath: str, filename: str):
@@ -825,14 +802,19 @@ class MinioUtil:
         return True
 
     @classmethod
-    def download(cls, conf: dict, bucket: str, dstfilepath: str, srcfilepath: str):
+    def download(cls, conf: dict, bucket: str, srcfilepath: str, dstfilepath: str = None):
         """下载保存文件保存本地
         :param bucket: 桶分区名称
-        :param dstfilepath: 下载后保存的本地路径
         :param srcfilepath: minio桶分区下的路径
+        :param dstfilepath: 下载后保存的本地路径
         """
         cls._init(conf)
-        cls.CONN.fget_object(bucket, dstfilepath, srcfilepath)
+        if dstfilepath:
+            with open(dstfilepath, 'wb') as fw:
+                for data in cls.CONN.get_object(bucket, srcfilepath):
+                    fw.write(data)
+        else:
+            cls.CONN.fget_object(bucket, srcfilepath, srcfilepath)
 
 
 class RedisUtil:
@@ -851,20 +833,14 @@ class RedisUtil:
 
     @classmethod
     def _init(cls, conf: dict):
-        if cls.CONN is None:
-            cls.connect(conf)
-        elif cls.CFID != UniUtil.get_uuid(conf):
-            cls.connect(conf)
+        cls.connect(conf)
 
     @classmethod
     def connect(cls, conf: dict):
-        try:
-            cls.PREFIX = conf.pop('prefix')
-            pool = redis.ConnectionPool(**conf)
-            cls.CONN = redis.Redis(connection_pool=pool)
-            cls.CFID = UniUtil.get_uuid(conf)
-        except Exception as e:
-            print("redis init failed, please check the config", e)
+        cls.PREFIX = conf.pop('prefix')
+        pool = redis.ConnectionPool(**conf)
+        cls.CONN = redis.Redis(connection_pool=pool)
+        cls.CFID = UniUtil.get_uuid(conf)
 
     @classmethod
     def exist(cls, key: str):
